@@ -13,7 +13,7 @@ class FakeTask:
             pass
 
         def execute(self, inputs):
-            return None
+            return self.Outputs()
 
 
 class TestRunParallel(unittest.TestCase):
